@@ -18,6 +18,8 @@ class CompanyFilingResourceSchema(Schema):
     date = fields.DateTime(allow_none=True)
     title = fields.String(allow_none=True)
     type = fields.String(allow_none=True)
+    old_type = fields.String(allow_none=True)
+    type_score = fields.Float(allow_none=True)
     orig_file_url = fields.String(allow_none=True)
     is_deleted = fields.Boolean(allow_none=True)
     unprocessed = fields.Boolean(allow_none=True)
