@@ -12,6 +12,8 @@ class DocTextResourceSchema(Schema):
     news_id = fields.Integer(allow_none=True)
     sec_filing_id = fields.Integer(allow_none=True)
     company_filing_id = fields.Integer(allow_none=True)
+    company_scientific_link_id = fields.Integer(allow_none=True)
+    pubmed_id = fields.Integer(allow_none=True)
     text_type = fields.String(allow_none=True)
     text = fields.String(required=True)
     preferred = fields.Boolean(allow_none=True)
