@@ -20,10 +20,10 @@ class NCTDesignOutcomesModel(Base):
         nullable=False,
     )
     outcome_type = Column(String(128))
-    measure = Column(Text)
-    time_frame = Column(String(191))
-    description = Column(Text)
-    last_update_submitted_qc_date = Column(DateTime)
+    measure = Column(Text, nullable=True)
+    time_frame = Column(String(191), nullable=True)
+    description = Column(Text, nullable=True)
+    last_update_submitted_qc_date = Column(DateTime, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
