@@ -12,5 +12,5 @@ class NCTNewswireResourceSchema(Schema):
     nct_study_id = fields.Integer(required=True)
     news_id = fields.Integer(required=True)
     is_deleted = fields.Boolean(allow_none=True)
-    date = fields.Boolean(allow_none=True)
+    date = fields.DateTime(allow_none=True)
     updated_at = fields.DateTime(dump_only=True)
